Unnamed repository; edit this file 'description' to name the repository.
Diffstat (limited to 'crates/hir-ty/src/next_solver/binder.rs')
-rw-r--r--crates/hir-ty/src/next_solver/binder.rs5
1 files changed, 3 insertions, 2 deletions
diff --git a/crates/hir-ty/src/next_solver/binder.rs b/crates/hir-ty/src/next_solver/binder.rs
index 95f437165d..9585cced6b 100644
--- a/crates/hir-ty/src/next_solver/binder.rs
+++ b/crates/hir-ty/src/next_solver/binder.rs
@@ -1,5 +1,6 @@
use hir_def::TraitId;
use macros::{TypeFoldable, TypeVisitable};
+use salsa::Update;
use crate::next_solver::{
Binder, Clauses, DbInterner, EarlyBinder, FnSig, FnSigKind, GenericArg, PolyFnSig,
@@ -7,7 +8,7 @@ use crate::next_solver::{
TraitRef, Ty,
};
#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
pub struct StoredEarlyBinder<T>(T);
impl<T> StoredEarlyBinder<T> {
@@ -102,7 +103,7 @@ impl StoredPolyFnSig {
}
}
#[derive(Debug, Clone, PartialEq, Eq, Hash, TypeVisitable, TypeFoldable)]
pub struct StoredTraitRef {
#[type_visitable(ignore)]
def_id: TraitId,
@@ -7,7 +8,7 @@ use crate::next_solver::{
TraitRef, Ty,
};
-#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash, Update)]
pub struct StoredEarlyBinder<T>(T);
impl<T> StoredEarlyBinder<T> {
@@ -102,7 +103,7 @@ impl StoredPolyFnSig {
}
}
-#[derive(Debug, Clone, PartialEq, Eq, Hash, TypeVisitable, TypeFoldable)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, TypeVisitable, TypeFoldable, Update)]
pub struct StoredTraitRef {
#[type_visitable(ignore)]